.. -*- coding: utf-8 -*-

.. _DataAsObjects:

Data as objects
===============

In this chapter, we will introduce the objects that are used to handle
the logic associated to the data stored in the database.

.. toctree::
   :maxdepth: 1

   data-as-objects
   load-sort
   adapters
   application-logic
